import java.io.IOException;
import java.nio.file.*;
import java.nio.file.attribute.BasicFileAttributes;

public class Main {

    /**
     * Функция для проверки аргументов командной строки
     *
     * @param args аргументы командной строки
     * @return true, если мы корректно передали неообходимые аргументы,
     * и false в противном случае
     */
    private static boolean checkArgs(String[] args) {
        if (args.length == 0) {
            System.out.println("Введите путь до папки, содержимое которой хотите скопировать");
            return false;
        }

        if (args.length == 1) {
            System.out.println("Введите путь до папки, в которую хотите скопировать содержимое исходной папки");
            return false;
        }

        String dirSourceName = args[0];
        Path dirSource = Paths.get(dirSourceName);
        if (Files.notExists(dirSource)) {
            System.out.println("Папка " + dirSourceName + " не существует");
            return false;
        }

        if (!Files.isDirectory(dirSource)) {
            System.out.println("Введите путь до папки, содержимое которой хотите скопировать");
            return false;
        }

        String dirTargetName = args[1];
        Path dirTarget = Paths.get(dirTargetName);
        if (Files.notExists(dirTarget)) {
            System.out.println("Папка " + dirTargetName + " не существует");
            return false;
        }

        if (!Files.isDirectory(dirTarget)) {
            System.out.println("Введите путь до папки, в которую хотите скопировать содержимое исходной папки");
            return false;
        }

        return true;
    }

    private static void solve(String[] args) throws IOException {
        String dirSourceName = args[0];
        String dirTargetName = args[1];

        Path dirSource = Paths.get(dirSourceName);
        Path dirTarget = Paths.get(dirTargetName);

        Files.walkFileTree(dirSource, new SimpleFileVisitor<Path>() {
            private void copyObject(Path source) throws IOException {
                if (!Files.isSameFile(source, dirSource)) {
                    /* Получаем путь объекта относительно исходной папки */
                    Path subPath = source.subpath(dirSource.getNameCount(), source.getNameCount());
                    System.out.print("Копирование " + subPath.toString() + " - ");

                    /* Определяем путь нового объекта */
                    String targetName = dirTarget.toAbsolutePath().toString() + "/" + subPath.toString();

                    try {
                        /* Копируем объект */
                        Files.copy(source, Paths.get(targetName), StandardCopyOption.REPLACE_EXISTING);
                        System.out.println("успешно");
                    } catch (DirectoryNotEmptyException e) {
                        System.out.println("неуспешно");
                    }
                }
            }

            @Override
            public FileVisitResult preVisitDirectory(Path dir, BasicFileAttributes attrs) throws IOException {
                copyObject(dir);

                return FileVisitResult.CONTINUE;
            }

            @Override
            public FileVisitResult visitFile(Path file, BasicFileAttributes attrs) throws IOException {
                copyObject(file);

                return FileVisitResult.CONTINUE;
            }
        });
    }

    public static void main(String[] args) throws IOException {
        if (checkArgs(args)) {
            solve(args);
        }
    }
}
